@@ -5,11 +5,9 @@
 
 
 import asyncio
-import datetime
 import logging
-import neohubapi.neohub as neohub
 
-from neohubapi.enums import ScheduleFormat
+from neohubapi import neohub
 
 
 async def run():
@@ -17,12 +15,12 @@ async def run():
     system = await hub.get_system()
     hub_data, devices = await hub.get_live_data()
     print("Thermostats:")
-    for device in devices['thermostats']:
+    for device in devices["thermostats"]:
         print(f"Target temperature of {device.name}: {device.target_temperature}")
         await device.identify()
 
     print("Timeclocks:")
-    for device in devices['timeclocks']:
+    for device in devices["timeclocks"]:
         print(f"Timeclock {device.name}: {device.target_temperature}")
         print(await hub.set_timer_hold(False, 1, [device]))
 
@@ -33,5 +31,6 @@ def main():
     logging.basicConfig(level=logging.DEBUG)
     asyncio.run(run())
 
-if (__name__ == '__main__'):
+
+if __name__ == "__main__":
     main()
