@@ -2,13 +2,21 @@
 
 # SPDX-FileCopyrightText: 2020 Andrius Štikonas <andrius@stikonas.eu>
 # SPDX-License-Identifier: LGPL-3.0-or-later
+"""Enums for neohubapi."""
 
 import enum
 
+ATTR_LIVE = "live"
+ATTR_DEVICES = "devices"
+ATTR_SYSTEM = "system"
+ATTR_PROFILES = "profiles"
+ATTR_PROFILES_0 = "profiles_0"
+ATTR_TIMER_PROFILES = "timer_profiles"
+ATTR_TIMER_PROFILES_0 = "timer_profiles_0"
+
 
 class ScheduleFormat(enum.Enum):
-    """
-    Enum to specify Schedule Format
+    """Enum to specify Schedule Format.
 
     ZERO  - non programmable (time clocks cannot be non programmable)
     ONE   - same format every day of the week
@@ -23,21 +31,23 @@ class ScheduleFormat(enum.Enum):
 
 
 def schedule_format_int_to_enum(int_format):
+    """Convert schedule int to enum."""
     if int_format is None:
         return None
     if int_format == 0:
         return ScheduleFormat.ZERO
-    elif int_format == 1:
+    if int_format == 1:
         return ScheduleFormat.ONE
-    elif int_format == 2:
+    if int_format == 2:
         return ScheduleFormat.TWO
-    elif int_format == 4:
+    if int_format == 4:
         return ScheduleFormat.SEVEN
-    else:
-        raise ValueError('Unrecognized ScheduleFormat')
+    raise ValueError("Unrecognized ScheduleFormat")
 
 
 class Weekday(enum.Enum):
+    """Weekdays."""
+
     MONDAY = "monday"
     TUESDAY = "tuesday"
     WEDNESDAY = "wednesday"
@@ -48,6 +58,8 @@ class Weekday(enum.Enum):
 
 
 class HCMode(enum.Enum):
+    """Modes for HC devices."""
+
     AUTO = "AUTO"
     COOLING = "COOLING"
     HEATING = "HEATING"
