@@ -1,16 +1,17 @@
 import asyncio
 import json
-import pytest
 import time
 from types import SimpleNamespace
 
 import neohubapi
+import pytest
 
 HOST = 'localhost'
 
 
 class FakeProtocol(asyncio.Protocol):
     """A simple asyncio protocol that returns a given message."""
+
     def connection_made(self, transport):
         self.transport = transport
 
@@ -43,7 +44,7 @@ class FakeServer:
         await server.wait_closed()
 
 
-@pytest.fixture()
+@pytest.fixture
 async def fakeserver(event_loop):
     """Create a fakeserver pytest fixture."""
     server = FakeServer(event_loop, 4242)
